import { AbstractFileSystem, SourceCodeType, UriString, IsValidSchema, Mode } from '@shopify/theme-check-common';
import { Connection } from 'vscode-languageserver';
import { ClientCapabilities } from '../ClientCapabilities';
import { AugmentedSourceCode } from './types';
export declare class DocumentManager {
    private readonly fs?;
    private readonly connection?;
    private readonly clientCapabilities?;
    private readonly getModeForUri?;
    private readonly isValidSchema?;
    /**
     * The sourceCodes map is a map of URIs to SourceCodes. It is used to keep
     * track of all the open documents in the workspace as well as caching the ASTs
     * of the documents.
     *
     * Files that are opened in the editor have a defined version, while files that
     * are preloaded have a version of `undefined`.
     */
    private sourceCodes;
    constructor(fs?: AbstractFileSystem | undefined, connection?: Connection | undefined, clientCapabilities?: ClientCapabilities | undefined, getModeForUri?: ((uri: UriString) => Promise<Mode>) | undefined, isValidSchema?: IsValidSchema | undefined);
    open(uri: UriString, source: string, version: number | undefined): void;
    change(uri: UriString, source: string, version: number | undefined): void;
    close(uri: UriString): void;
    delete(uri: UriString): boolean;
    rename(oldUri: UriString, newUri: UriString): void;
    theme(root: UriString, includeFilesFromDisk?: boolean): AugmentedSourceCode[];
    get openDocuments(): AugmentedSourceCode[];
    get(uri: UriString): AugmentedSourceCode<SourceCodeType> | undefined;
    has(uri: UriString): boolean;
    private set;
    /**
     * The preload method is used to pre-load and pre-parse all the files in the
     * theme. It is smart and only will load files that are not already in the
     * DocumentManager.
     *
     * Files that are loaded from the AbstractFileSystem will have a version of `undefined`.
     */
    preload: {
        (arg: string): Promise<void>;
        force(arg: string): Promise<void>;
        invalidate(arg: string): void;
    };
    private augmentedSourceCode;
}
